@@ -1,9 +1,22 @@
 /*
-    This file is part of the kholidays library.
+  This file is part of the kholidays library.
 
-    SPDX-FileCopyrightText: 2010 John Layt <john@layt.net>
+  Copyright 2010 John Layt <john@layt.net>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
+
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU Library General Public License for more details.
+
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to the
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #ifndef KHOLIDAYS_HOLIDAYPARSERDRIVER_P_H
@@ -18,12 +31,13 @@
 
 namespace KHolidays
 {
+
 /**
  * HolidayParserDriver abstract base class
  *
  * Defines a standard interface for parsing holiday files of various formats
  *
- * Derived classes must implement method parse(), other methods should work for
+ * Derived classes must implemet method parse(), other methods should work for
  * most circumstances
  *
  * @internal Private, for internal use only
@@ -31,6 +45,7 @@ namespace KHolidays
 class HolidayParserDriver
 {
 public:
+
     /**
      * Constructor of abstract holiday file parser driver class.
      * This will be called by derived classes.
@@ -79,18 +94,7 @@ public:
     virtual QString fileDescription() const;
 
     /**
-     * Return a list of holidays falling between any two dates with category
-     *
-     * @param startDate start date of the holiday parse range
-     * @param endDate end date of the holiday parse range
-     * @param category only holidays with corresponing category
-     *
-     * @return a list of holidays
-     */
-    virtual Holiday::List parseHolidays(const QDate &startDate, const QDate &endDate, const QString &category);
-
-    /**
-     * Return a list of holidays falling between any two dates inclusive astro seasons
+     * Return a list of holidays falling between any two dates
      *
      * @param startDate start date of the holiday parse range
      * @param endDate end date of the holiday parse range
@@ -109,16 +113,6 @@ public:
      */
     virtual Holiday::List parseHolidays(const QDate &date);
 
-    /**
-     * Return a list of holidays falling between any two dates without astro seasons
-     *
-     * @param startDate start date of the holiday parse range
-     * @param endDate end date of the holiday parse range
-     *
-     * @return a list of holidays
-     */
-    virtual Holiday::List parseRawHolidays(const QDate &startDate, const QDate &endDate);
-
     /**
      * Convenience function
      * Return a list of holidays falling in a given calendar year
@@ -128,7 +122,8 @@ public:
      *
      * @return a list of holidays
      */
-    virtual Holiday::List parseHolidays(int calendarYear, QCalendarSystem::CalendarSystem calendar = QCalendarSystem::GregorianCalendar);
+    virtual Holiday::List parseHolidays(int calendarYear,
+                                        QCalendarSystem::CalendarSystem calendar = QCalendarSystem::GregorianCalendar);
 
     /**
      * Standard error message handling
@@ -160,22 +155,22 @@ protected:
      */
     virtual void setParseStartEnd();
 
-    QString m_filePath; // File to be parsed
+    QString          m_filePath;           // File to be parsed
 
-    QString m_fileCountryCode; // File country code in ISO 3166-2 standard
-    QString m_fileLanguageCode; // File language
-    QString m_fileName; // File name
-    QString m_fileDescription; // File description
+    QString          m_fileCountryCode;    // File country code in ISO 3166-2 standard
+    QString          m_fileLanguageCode;   // File language
+    QString          m_fileName;           // File name
+    QString          m_fileDescription;    // File description
 
-    QDate m_requestStart; // First day of period being requested
-    QDate m_requestEnd; // Last day of period being requested
+    QDate            m_requestStart;       // First day of period being requested
+    QDate            m_requestEnd;         // Last day of period being requested
 
-    Holiday::List m_resultList; // List of requested holidays
+    Holiday::List    m_resultList;         // List of requested holidays
 
-    QCalendarSystem m_parseCalendar; // Calendar system being parsed
-    int m_parseYear; // Year currently being parsed
-    int m_parseStartYear; // First year to parse in parse calendar
-    int m_parseEndYear; // Last year to parse in parse calendar
+    QCalendarSystem  m_parseCalendar;      // Calendar system being parsed
+    int              m_parseYear;          // Year currently being parsed
+    int              m_parseStartYear;     // First year to parse in parse calendar
+    int              m_parseEndYear;       // Last year to parse in parse calendar
 };
 
 }
